/* highlighter.c generated by valac, the Vala compiler
 * generated from highlighter.vala, do not modify */

/* codehighlighter.vala
 *
 * Copyright (C) 2015       Florian Brosch
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Florian Brosch <flo.brosch@gmail.com>
 */

#include "valadoc.h"
#include <valagee.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	VALADOC_HIGHLIGHTER_HIGHLIGHTER_0_PROPERTY,
	VALADOC_HIGHLIGHTER_HIGHLIGHTER_NUM_PROPERTIES
};
static GParamSpec* valadoc_highlighter_highlighter_properties[VALADOC_HIGHLIGHTER_HIGHLIGHTER_NUM_PROPERTIES];
#define _vala_map_unref0(var) ((var == NULL) ? NULL : (var = (vala_map_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _valadoc_highlighter_code_token_unref0(var) ((var == NULL) ? NULL : (var = (valadoc_highlighter_code_token_unref (var), NULL)))

struct _ValadocHighlighterHighlighterPrivate {
	ValaHashMap* vala_keywords;
	ValaHashMap* c_keywords;
};

static gint ValadocHighlighterHighlighter_private_offset;
static gpointer valadoc_highlighter_highlighter_parent_class = NULL;

static ValadocHighlighterCodeTokenType* _valadoc_highlighter_code_token_type_dup (ValadocHighlighterCodeTokenType* self);
static ValadocContentRun* valadoc_highlighter_highlighter_highlight_code (ValadocHighlighterHighlighter* self,
                                                                   ValadocHighlighterScanner* scanner);
 G_GNUC_INTERNAL ValadocContentRun* valadoc_content_run_new (ValadocContentRunStyle style);
 G_GNUC_INTERNAL ValadocContentRun* valadoc_content_run_construct (GType object_type,
                                                  ValadocContentRunStyle style);
 G_GNUC_INTERNAL ValadocContentText* valadoc_content_text_new (const gchar* text);
 G_GNUC_INTERNAL ValadocContentText* valadoc_content_text_construct (GType object_type,
                                                    const gchar* text);
static void valadoc_highlighter_highlighter_finalize (GObject * obj);
static GType valadoc_highlighter_highlighter_get_type_once (void);

static inline gpointer
valadoc_highlighter_highlighter_get_instance_private (ValadocHighlighterHighlighter* self)
{
	return G_STRUCT_MEMBER_P (self, ValadocHighlighterHighlighter_private_offset);
}

/**
 * Used to highlight vala source code.
 */
static ValadocHighlighterCodeTokenType*
_valadoc_highlighter_code_token_type_dup (ValadocHighlighterCodeTokenType* self)
{
	ValadocHighlighterCodeTokenType* dup;
	dup = g_new0 (ValadocHighlighterCodeTokenType, 1);
	memcpy (dup, self, sizeof (ValadocHighlighterCodeTokenType));
	return dup;
}

ValadocContentRun*
valadoc_highlighter_highlighter_highlight_vala (ValadocHighlighterHighlighter* self,
                                                const gchar* source_code)
{
	ValaHashMap* _tmp0_;
	gboolean enable_string_templates = FALSE;
	gboolean enable_preprocessor_define = FALSE;
	gboolean enable_preprocessor_include = FALSE;
	gboolean enable_keyword_escape = FALSE;
	gboolean enabel_verbatim_string = FALSE;
	ValadocHighlighterCodeScanner* scanner = NULL;
	ValaHashMap* _tmp195_;
	ValadocHighlighterCodeScanner* _tmp196_;
	ValadocContentRun* _tmp197_;
	ValadocContentRun* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (source_code != NULL, NULL);
	_tmp0_ = self->priv->vala_keywords;
	if (_tmp0_ == NULL) {
		GHashFunc _tmp1_;
		GEqualFunc _tmp2_;
		GEqualFunc _tmp3_;
		ValaHashMap* _tmp4_;
		ValaHashMap* _tmp5_;
		ValadocHighlighterCodeTokenType _tmp6_;
		ValaHashMap* _tmp7_;
		ValadocHighlighterCodeTokenType _tmp8_;
		ValaHashMap* _tmp9_;
		ValadocHighlighterCodeTokenType _tmp10_;
		ValaHashMap* _tmp11_;
		ValadocHighlighterCodeTokenType _tmp12_;
		ValaHashMap* _tmp13_;
		ValadocHighlighterCodeTokenType _tmp14_;
		ValaHashMap* _tmp15_;
		ValadocHighlighterCodeTokenType _tmp16_;
		ValaHashMap* _tmp17_;
		ValadocHighlighterCodeTokenType _tmp18_;
		ValaHashMap* _tmp19_;
		ValadocHighlighterCodeTokenType _tmp20_;
		ValaHashMap* _tmp21_;
		ValadocHighlighterCodeTokenType _tmp22_;
		ValaHashMap* _tmp23_;
		ValadocHighlighterCodeTokenType _tmp24_;
		ValaHashMap* _tmp25_;
		ValadocHighlighterCodeTokenType _tmp26_;
		ValaHashMap* _tmp27_;
		ValadocHighlighterCodeTokenType _tmp28_;
		ValaHashMap* _tmp29_;
		ValadocHighlighterCodeTokenType _tmp30_;
		ValaHashMap* _tmp31_;
		ValadocHighlighterCodeTokenType _tmp32_;
		ValaHashMap* _tmp33_;
		ValadocHighlighterCodeTokenType _tmp34_;
		ValaHashMap* _tmp35_;
		ValadocHighlighterCodeTokenType _tmp36_;
		ValaHashMap* _tmp37_;
		ValadocHighlighterCodeTokenType _tmp38_;
		ValaHashMap* _tmp39_;
		ValadocHighlighterCodeTokenType _tmp40_;
		ValaHashMap* _tmp41_;
		ValadocHighlighterCodeTokenType _tmp42_;
		ValaHashMap* _tmp43_;
		ValadocHighlighterCodeTokenType _tmp44_;
		ValaHashMap* _tmp45_;
		ValadocHighlighterCodeTokenType _tmp46_;
		ValaHashMap* _tmp47_;
		ValadocHighlighterCodeTokenType _tmp48_;
		ValaHashMap* _tmp49_;
		ValadocHighlighterCodeTokenType _tmp50_;
		ValaHashMap* _tmp51_;
		ValadocHighlighterCodeTokenType _tmp52_;
		ValaHashMap* _tmp53_;
		ValadocHighlighterCodeTokenType _tmp54_;
		ValaHashMap* _tmp55_;
		ValadocHighlighterCodeTokenType _tmp56_;
		ValaHashMap* _tmp57_;
		ValadocHighlighterCodeTokenType _tmp58_;
		ValaHashMap* _tmp59_;
		ValadocHighlighterCodeTokenType _tmp60_;
		ValaHashMap* _tmp61_;
		ValadocHighlighterCodeTokenType _tmp62_;
		ValaHashMap* _tmp63_;
		ValadocHighlighterCodeTokenType _tmp64_;
		ValaHashMap* _tmp65_;
		ValadocHighlighterCodeTokenType _tmp66_;
		ValaHashMap* _tmp67_;
		ValadocHighlighterCodeTokenType _tmp68_;
		ValaHashMap* _tmp69_;
		ValadocHighlighterCodeTokenType _tmp70_;
		ValaHashMap* _tmp71_;
		ValadocHighlighterCodeTokenType _tmp72_;
		ValaHashMap* _tmp73_;
		ValadocHighlighterCodeTokenType _tmp74_;
		ValaHashMap* _tmp75_;
		ValadocHighlighterCodeTokenType _tmp76_;
		ValaHashMap* _tmp77_;
		ValadocHighlighterCodeTokenType _tmp78_;
		ValaHashMap* _tmp79_;
		ValadocHighlighterCodeTokenType _tmp80_;
		ValaHashMap* _tmp81_;
		ValadocHighlighterCodeTokenType _tmp82_;
		ValaHashMap* _tmp83_;
		ValadocHighlighterCodeTokenType _tmp84_;
		ValaHashMap* _tmp85_;
		ValadocHighlighterCodeTokenType _tmp86_;
		ValaHashMap* _tmp87_;
		ValadocHighlighterCodeTokenType _tmp88_;
		ValaHashMap* _tmp89_;
		ValadocHighlighterCodeTokenType _tmp90_;
		ValaHashMap* _tmp91_;
		ValadocHighlighterCodeTokenType _tmp92_;
		ValaHashMap* _tmp93_;
		ValadocHighlighterCodeTokenType _tmp94_;
		ValaHashMap* _tmp95_;
		ValadocHighlighterCodeTokenType _tmp96_;
		ValaHashMap* _tmp97_;
		ValadocHighlighterCodeTokenType _tmp98_;
		ValaHashMap* _tmp99_;
		ValadocHighlighterCodeTokenType _tmp100_;
		ValaHashMap* _tmp101_;
		ValadocHighlighterCodeTokenType _tmp102_;
		ValaHashMap* _tmp103_;
		ValadocHighlighterCodeTokenType _tmp104_;
		ValaHashMap* _tmp105_;
		ValadocHighlighterCodeTokenType _tmp106_;
		ValaHashMap* _tmp107_;
		ValadocHighlighterCodeTokenType _tmp108_;
		ValaHashMap* _tmp109_;
		ValadocHighlighterCodeTokenType _tmp110_;
		ValaHashMap* _tmp111_;
		ValadocHighlighterCodeTokenType _tmp112_;
		ValaHashMap* _tmp113_;
		ValadocHighlighterCodeTokenType _tmp114_;
		ValaHashMap* _tmp115_;
		ValadocHighlighterCodeTokenType _tmp116_;
		ValaHashMap* _tmp117_;
		ValadocHighlighterCodeTokenType _tmp118_;
		ValaHashMap* _tmp119_;
		ValadocHighlighterCodeTokenType _tmp120_;
		ValaHashMap* _tmp121_;
		ValadocHighlighterCodeTokenType _tmp122_;
		ValaHashMap* _tmp123_;
		ValadocHighlighterCodeTokenType _tmp124_;
		ValaHashMap* _tmp125_;
		ValadocHighlighterCodeTokenType _tmp126_;
		ValaHashMap* _tmp127_;
		ValadocHighlighterCodeTokenType _tmp128_;
		ValaHashMap* _tmp129_;
		ValadocHighlighterCodeTokenType _tmp130_;
		ValaHashMap* _tmp131_;
		ValadocHighlighterCodeTokenType _tmp132_;
		ValaHashMap* _tmp133_;
		ValadocHighlighterCodeTokenType _tmp134_;
		ValaHashMap* _tmp135_;
		ValadocHighlighterCodeTokenType _tmp136_;
		ValaHashMap* _tmp137_;
		ValadocHighlighterCodeTokenType _tmp138_;
		ValaHashMap* _tmp139_;
		ValadocHighlighterCodeTokenType _tmp140_;
		ValaHashMap* _tmp141_;
		ValadocHighlighterCodeTokenType _tmp142_;
		ValaHashMap* _tmp143_;
		ValadocHighlighterCodeTokenType _tmp144_;
		ValaHashMap* _tmp145_;
		ValadocHighlighterCodeTokenType _tmp146_;
		ValaHashMap* _tmp147_;
		ValadocHighlighterCodeTokenType _tmp148_;
		ValaHashMap* _tmp149_;
		ValadocHighlighterCodeTokenType _tmp150_;
		ValaHashMap* _tmp151_;
		ValadocHighlighterCodeTokenType _tmp152_;
		ValaHashMap* _tmp153_;
		ValadocHighlighterCodeTokenType _tmp154_;
		ValaHashMap* _tmp155_;
		ValadocHighlighterCodeTokenType _tmp156_;
		ValaHashMap* _tmp157_;
		ValadocHighlighterCodeTokenType _tmp158_;
		ValaHashMap* _tmp159_;
		ValadocHighlighterCodeTokenType _tmp160_;
		ValaHashMap* _tmp161_;
		ValadocHighlighterCodeTokenType _tmp162_;
		ValaHashMap* _tmp163_;
		ValadocHighlighterCodeTokenType _tmp164_;
		ValaHashMap* _tmp165_;
		ValadocHighlighterCodeTokenType _tmp166_;
		ValaHashMap* _tmp167_;
		ValadocHighlighterCodeTokenType _tmp168_;
		ValaHashMap* _tmp169_;
		ValadocHighlighterCodeTokenType _tmp170_;
		ValaHashMap* _tmp171_;
		ValadocHighlighterCodeTokenType _tmp172_;
		ValaHashMap* _tmp173_;
		ValadocHighlighterCodeTokenType _tmp174_;
		ValaHashMap* _tmp175_;
		ValadocHighlighterCodeTokenType _tmp176_;
		ValaHashMap* _tmp177_;
		ValadocHighlighterCodeTokenType _tmp178_;
		ValaHashMap* _tmp179_;
		ValadocHighlighterCodeTokenType _tmp180_;
		ValaHashMap* _tmp181_;
		ValadocHighlighterCodeTokenType _tmp182_;
		ValaHashMap* _tmp183_;
		ValadocHighlighterCodeTokenType _tmp184_;
		ValaHashMap* _tmp185_;
		ValadocHighlighterCodeTokenType _tmp186_;
		ValaHashMap* _tmp187_;
		ValadocHighlighterCodeTokenType _tmp188_;
		ValaHashMap* _tmp189_;
		ValadocHighlighterCodeTokenType _tmp190_;
		ValaHashMap* _tmp191_;
		ValadocHighlighterCodeTokenType _tmp192_;
		ValaHashMap* _tmp193_;
		ValadocHighlighterCodeTokenType _tmp194_;
		_tmp1_ = g_str_hash;
		_tmp2_ = g_str_equal;
		_tmp3_ = g_direct_equal;
		_tmp4_ = vala_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, VALADOC_HIGHLIGHTER_TYPE_CODE_TOKEN_TYPE, (GBoxedCopyFunc) _valadoc_highlighter_code_token_type_dup, (GDestroyNotify) g_free, _tmp1_, _tmp2_, _tmp3_);
		_vala_map_unref0 (self->priv->vala_keywords);
		self->priv->vala_keywords = _tmp4_;
		_tmp5_ = self->priv->vala_keywords;
		_tmp6_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp5_, "string", (gpointer) ((gintptr) (&_tmp6_)));
		_tmp7_ = self->priv->vala_keywords;
		_tmp8_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp7_, "bool", (gpointer) ((gintptr) (&_tmp8_)));
		_tmp9_ = self->priv->vala_keywords;
		_tmp10_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp9_, "void", (gpointer) ((gintptr) (&_tmp10_)));
		_tmp11_ = self->priv->vala_keywords;
		_tmp12_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp11_, "double", (gpointer) ((gintptr) (&_tmp12_)));
		_tmp13_ = self->priv->vala_keywords;
		_tmp14_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp13_, "float", (gpointer) ((gintptr) (&_tmp14_)));
		_tmp15_ = self->priv->vala_keywords;
		_tmp16_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp15_, "char", (gpointer) ((gintptr) (&_tmp16_)));
		_tmp17_ = self->priv->vala_keywords;
		_tmp18_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp17_, "uchar", (gpointer) ((gintptr) (&_tmp18_)));
		_tmp19_ = self->priv->vala_keywords;
		_tmp20_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp19_, "unichar", (gpointer) ((gintptr) (&_tmp20_)));
		_tmp21_ = self->priv->vala_keywords;
		_tmp22_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp21_, "short", (gpointer) ((gintptr) (&_tmp22_)));
		_tmp23_ = self->priv->vala_keywords;
		_tmp24_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp23_, "ushort", (gpointer) ((gintptr) (&_tmp24_)));
		_tmp25_ = self->priv->vala_keywords;
		_tmp26_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp25_, "long", (gpointer) ((gintptr) (&_tmp26_)));
		_tmp27_ = self->priv->vala_keywords;
		_tmp28_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp27_, "ulong", (gpointer) ((gintptr) (&_tmp28_)));
		_tmp29_ = self->priv->vala_keywords;
		_tmp30_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp29_, "size_t", (gpointer) ((gintptr) (&_tmp30_)));
		_tmp31_ = self->priv->vala_keywords;
		_tmp32_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp31_, "ssize_t", (gpointer) ((gintptr) (&_tmp32_)));
		_tmp33_ = self->priv->vala_keywords;
		_tmp34_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp33_, "int", (gpointer) ((gintptr) (&_tmp34_)));
		_tmp35_ = self->priv->vala_keywords;
		_tmp36_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp35_, "int8", (gpointer) ((gintptr) (&_tmp36_)));
		_tmp37_ = self->priv->vala_keywords;
		_tmp38_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp37_, "int16", (gpointer) ((gintptr) (&_tmp38_)));
		_tmp39_ = self->priv->vala_keywords;
		_tmp40_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp39_, "int32", (gpointer) ((gintptr) (&_tmp40_)));
		_tmp41_ = self->priv->vala_keywords;
		_tmp42_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp41_, "int64", (gpointer) ((gintptr) (&_tmp42_)));
		_tmp43_ = self->priv->vala_keywords;
		_tmp44_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp43_, "uint", (gpointer) ((gintptr) (&_tmp44_)));
		_tmp45_ = self->priv->vala_keywords;
		_tmp46_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp45_, "uint8", (gpointer) ((gintptr) (&_tmp46_)));
		_tmp47_ = self->priv->vala_keywords;
		_tmp48_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp47_, "uint16", (gpointer) ((gintptr) (&_tmp48_)));
		_tmp49_ = self->priv->vala_keywords;
		_tmp50_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp49_, "uint32", (gpointer) ((gintptr) (&_tmp50_)));
		_tmp51_ = self->priv->vala_keywords;
		_tmp52_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp51_, "uint64", (gpointer) ((gintptr) (&_tmp52_)));
		_tmp53_ = self->priv->vala_keywords;
		_tmp54_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_LITERAL;
		vala_map_set ((ValaMap*) _tmp53_, "null", (gpointer) ((gintptr) (&_tmp54_)));
		_tmp55_ = self->priv->vala_keywords;
		_tmp56_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_LITERAL;
		vala_map_set ((ValaMap*) _tmp55_, "true", (gpointer) ((gintptr) (&_tmp56_)));
		_tmp57_ = self->priv->vala_keywords;
		_tmp58_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_LITERAL;
		vala_map_set ((ValaMap*) _tmp57_, "false", (gpointer) ((gintptr) (&_tmp58_)));
		_tmp59_ = self->priv->vala_keywords;
		_tmp60_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp59_, "return", (gpointer) ((gintptr) (&_tmp60_)));
		_tmp61_ = self->priv->vala_keywords;
		_tmp62_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp61_, "lock", (gpointer) ((gintptr) (&_tmp62_)));
		_tmp63_ = self->priv->vala_keywords;
		_tmp64_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp63_, "unlock", (gpointer) ((gintptr) (&_tmp64_)));
		_tmp65_ = self->priv->vala_keywords;
		_tmp66_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp65_, "var", (gpointer) ((gintptr) (&_tmp66_)));
		_tmp67_ = self->priv->vala_keywords;
		_tmp68_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp67_, "yield", (gpointer) ((gintptr) (&_tmp68_)));
		_tmp69_ = self->priv->vala_keywords;
		_tmp70_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp69_, "global", (gpointer) ((gintptr) (&_tmp70_)));
		_tmp71_ = self->priv->vala_keywords;
		_tmp72_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp71_, "construct", (gpointer) ((gintptr) (&_tmp72_)));
		_tmp73_ = self->priv->vala_keywords;
		_tmp74_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp73_, "value", (gpointer) ((gintptr) (&_tmp74_)));
		_tmp75_ = self->priv->vala_keywords;
		_tmp76_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp75_, "get", (gpointer) ((gintptr) (&_tmp76_)));
		_tmp77_ = self->priv->vala_keywords;
		_tmp78_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp77_, "set", (gpointer) ((gintptr) (&_tmp78_)));
		_tmp79_ = self->priv->vala_keywords;
		_tmp80_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp79_, "owned", (gpointer) ((gintptr) (&_tmp80_)));
		_tmp81_ = self->priv->vala_keywords;
		_tmp82_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp81_, "unowned", (gpointer) ((gintptr) (&_tmp82_)));
		_tmp83_ = self->priv->vala_keywords;
		_tmp84_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp83_, "const", (gpointer) ((gintptr) (&_tmp84_)));
		_tmp85_ = self->priv->vala_keywords;
		_tmp86_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp85_, "weak", (gpointer) ((gintptr) (&_tmp86_)));
		_tmp87_ = self->priv->vala_keywords;
		_tmp88_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp87_, "dynamic", (gpointer) ((gintptr) (&_tmp88_)));
		_tmp89_ = self->priv->vala_keywords;
		_tmp90_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp89_, "out", (gpointer) ((gintptr) (&_tmp90_)));
		_tmp91_ = self->priv->vala_keywords;
		_tmp92_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp91_, "ref", (gpointer) ((gintptr) (&_tmp92_)));
		_tmp93_ = self->priv->vala_keywords;
		_tmp94_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp93_, "break", (gpointer) ((gintptr) (&_tmp94_)));
		_tmp95_ = self->priv->vala_keywords;
		_tmp96_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp95_, "continue", (gpointer) ((gintptr) (&_tmp96_)));
		_tmp97_ = self->priv->vala_keywords;
		_tmp98_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp97_, "return", (gpointer) ((gintptr) (&_tmp98_)));
		_tmp99_ = self->priv->vala_keywords;
		_tmp100_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp99_, "if", (gpointer) ((gintptr) (&_tmp100_)));
		_tmp101_ = self->priv->vala_keywords;
		_tmp102_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp101_, "else", (gpointer) ((gintptr) (&_tmp102_)));
		_tmp103_ = self->priv->vala_keywords;
		_tmp104_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp103_, "switch", (gpointer) ((gintptr) (&_tmp104_)));
		_tmp105_ = self->priv->vala_keywords;
		_tmp106_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp105_, "case", (gpointer) ((gintptr) (&_tmp106_)));
		_tmp107_ = self->priv->vala_keywords;
		_tmp108_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp107_, "default", (gpointer) ((gintptr) (&_tmp108_)));
		_tmp109_ = self->priv->vala_keywords;
		_tmp110_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp109_, "do", (gpointer) ((gintptr) (&_tmp110_)));
		_tmp111_ = self->priv->vala_keywords;
		_tmp112_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp111_, "while", (gpointer) ((gintptr) (&_tmp112_)));
		_tmp113_ = self->priv->vala_keywords;
		_tmp114_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp113_, "for", (gpointer) ((gintptr) (&_tmp114_)));
		_tmp115_ = self->priv->vala_keywords;
		_tmp116_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp115_, "foreach", (gpointer) ((gintptr) (&_tmp116_)));
		_tmp117_ = self->priv->vala_keywords;
		_tmp118_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp117_, "in", (gpointer) ((gintptr) (&_tmp118_)));
		_tmp119_ = self->priv->vala_keywords;
		_tmp120_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp119_, "try", (gpointer) ((gintptr) (&_tmp120_)));
		_tmp121_ = self->priv->vala_keywords;
		_tmp122_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp121_, "catch", (gpointer) ((gintptr) (&_tmp122_)));
		_tmp123_ = self->priv->vala_keywords;
		_tmp124_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp123_, "finally", (gpointer) ((gintptr) (&_tmp124_)));
		_tmp125_ = self->priv->vala_keywords;
		_tmp126_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp125_, "throw", (gpointer) ((gintptr) (&_tmp126_)));
		_tmp127_ = self->priv->vala_keywords;
		_tmp128_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp127_, "class", (gpointer) ((gintptr) (&_tmp128_)));
		_tmp129_ = self->priv->vala_keywords;
		_tmp130_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp129_, "interface", (gpointer) ((gintptr) (&_tmp130_)));
		_tmp131_ = self->priv->vala_keywords;
		_tmp132_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp131_, "struct", (gpointer) ((gintptr) (&_tmp132_)));
		_tmp133_ = self->priv->vala_keywords;
		_tmp134_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp133_, "enum", (gpointer) ((gintptr) (&_tmp134_)));
		_tmp135_ = self->priv->vala_keywords;
		_tmp136_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp135_, "delegate", (gpointer) ((gintptr) (&_tmp136_)));
		_tmp137_ = self->priv->vala_keywords;
		_tmp138_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp137_, "errordomain", (gpointer) ((gintptr) (&_tmp138_)));
		_tmp139_ = self->priv->vala_keywords;
		_tmp140_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp139_, "abstract", (gpointer) ((gintptr) (&_tmp140_)));
		_tmp141_ = self->priv->vala_keywords;
		_tmp142_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp141_, "virtual", (gpointer) ((gintptr) (&_tmp142_)));
		_tmp143_ = self->priv->vala_keywords;
		_tmp144_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp143_, "override", (gpointer) ((gintptr) (&_tmp144_)));
		_tmp145_ = self->priv->vala_keywords;
		_tmp146_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp145_, "signal", (gpointer) ((gintptr) (&_tmp146_)));
		_tmp147_ = self->priv->vala_keywords;
		_tmp148_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp147_, "extern", (gpointer) ((gintptr) (&_tmp148_)));
		_tmp149_ = self->priv->vala_keywords;
		_tmp150_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp149_, "static", (gpointer) ((gintptr) (&_tmp150_)));
		_tmp151_ = self->priv->vala_keywords;
		_tmp152_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp151_, "async", (gpointer) ((gintptr) (&_tmp152_)));
		_tmp153_ = self->priv->vala_keywords;
		_tmp154_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp153_, "inline", (gpointer) ((gintptr) (&_tmp154_)));
		_tmp155_ = self->priv->vala_keywords;
		_tmp156_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp155_, "new", (gpointer) ((gintptr) (&_tmp156_)));
		_tmp157_ = self->priv->vala_keywords;
		_tmp158_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp157_, "public", (gpointer) ((gintptr) (&_tmp158_)));
		_tmp159_ = self->priv->vala_keywords;
		_tmp160_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp159_, "private", (gpointer) ((gintptr) (&_tmp160_)));
		_tmp161_ = self->priv->vala_keywords;
		_tmp162_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp161_, "protected", (gpointer) ((gintptr) (&_tmp162_)));
		_tmp163_ = self->priv->vala_keywords;
		_tmp164_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp163_, "internal", (gpointer) ((gintptr) (&_tmp164_)));
		_tmp165_ = self->priv->vala_keywords;
		_tmp166_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp165_, "throws", (gpointer) ((gintptr) (&_tmp166_)));
		_tmp167_ = self->priv->vala_keywords;
		_tmp168_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp167_, "requires", (gpointer) ((gintptr) (&_tmp168_)));
		_tmp169_ = self->priv->vala_keywords;
		_tmp170_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp169_, "ensures", (gpointer) ((gintptr) (&_tmp170_)));
		_tmp171_ = self->priv->vala_keywords;
		_tmp172_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp171_, "assert", (gpointer) ((gintptr) (&_tmp172_)));
		_tmp173_ = self->priv->vala_keywords;
		_tmp174_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp173_, "namespace", (gpointer) ((gintptr) (&_tmp174_)));
		_tmp175_ = self->priv->vala_keywords;
		_tmp176_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp175_, "using", (gpointer) ((gintptr) (&_tmp176_)));
		_tmp177_ = self->priv->vala_keywords;
		_tmp178_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp177_, "as", (gpointer) ((gintptr) (&_tmp178_)));
		_tmp179_ = self->priv->vala_keywords;
		_tmp180_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp179_, "is", (gpointer) ((gintptr) (&_tmp180_)));
		_tmp181_ = self->priv->vala_keywords;
		_tmp182_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp181_, "in", (gpointer) ((gintptr) (&_tmp182_)));
		_tmp183_ = self->priv->vala_keywords;
		_tmp184_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp183_, "new", (gpointer) ((gintptr) (&_tmp184_)));
		_tmp185_ = self->priv->vala_keywords;
		_tmp186_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp185_, "delete", (gpointer) ((gintptr) (&_tmp186_)));
		_tmp187_ = self->priv->vala_keywords;
		_tmp188_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp187_, "sizeof", (gpointer) ((gintptr) (&_tmp188_)));
		_tmp189_ = self->priv->vala_keywords;
		_tmp190_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp189_, "typeof", (gpointer) ((gintptr) (&_tmp190_)));
		_tmp191_ = self->priv->vala_keywords;
		_tmp192_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp191_, "this", (gpointer) ((gintptr) (&_tmp192_)));
		_tmp193_ = self->priv->vala_keywords;
		_tmp194_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp193_, "base", (gpointer) ((gintptr) (&_tmp194_)));
	}
	enable_string_templates = TRUE;
	enable_preprocessor_define = FALSE;
	enable_preprocessor_include = FALSE;
	enable_keyword_escape = TRUE;
	enabel_verbatim_string = TRUE;
	_tmp195_ = self->priv->vala_keywords;
	_tmp196_ = valadoc_highlighter_code_scanner_new (source_code, enable_string_templates, enabel_verbatim_string, enable_preprocessor_define, enable_preprocessor_include, enable_keyword_escape, _tmp195_);
	scanner = _tmp196_;
	_tmp197_ = valadoc_highlighter_highlighter_highlight_code (self, (ValadocHighlighterScanner*) scanner);
	result = _tmp197_;
	_g_object_unref0 (scanner);
	return result;
}

/**
 * Used to highlight C source code.
 */
ValadocContentRun*
valadoc_highlighter_highlighter_highlight_c (ValadocHighlighterHighlighter* self,
                                             const gchar* source_code)
{
	ValaHashMap* _tmp0_;
	gboolean enable_string_templates = FALSE;
	gboolean enable_preprocessor_define = FALSE;
	gboolean enable_preprocessor_include = FALSE;
	gboolean enable_keyword_escape = FALSE;
	gboolean enabel_verbatim_string = FALSE;
	ValadocHighlighterCodeScanner* scanner = NULL;
	ValaHashMap* _tmp129_;
	ValadocHighlighterCodeScanner* _tmp130_;
	ValadocContentRun* _tmp131_;
	ValadocContentRun* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (source_code != NULL, NULL);
	_tmp0_ = self->priv->c_keywords;
	if (_tmp0_ == NULL) {
		GHashFunc _tmp1_;
		GEqualFunc _tmp2_;
		GEqualFunc _tmp3_;
		ValaHashMap* _tmp4_;
		ValaHashMap* _tmp5_;
		ValadocHighlighterCodeTokenType _tmp6_;
		ValaHashMap* _tmp7_;
		ValadocHighlighterCodeTokenType _tmp8_;
		ValaHashMap* _tmp9_;
		ValadocHighlighterCodeTokenType _tmp10_;
		ValaHashMap* _tmp11_;
		ValadocHighlighterCodeTokenType _tmp12_;
		ValaHashMap* _tmp13_;
		ValadocHighlighterCodeTokenType _tmp14_;
		ValaHashMap* _tmp15_;
		ValadocHighlighterCodeTokenType _tmp16_;
		ValaHashMap* _tmp17_;
		ValadocHighlighterCodeTokenType _tmp18_;
		ValaHashMap* _tmp19_;
		ValadocHighlighterCodeTokenType _tmp20_;
		ValaHashMap* _tmp21_;
		ValadocHighlighterCodeTokenType _tmp22_;
		ValaHashMap* _tmp23_;
		ValadocHighlighterCodeTokenType _tmp24_;
		ValaHashMap* _tmp25_;
		ValadocHighlighterCodeTokenType _tmp26_;
		ValaHashMap* _tmp27_;
		ValadocHighlighterCodeTokenType _tmp28_;
		ValaHashMap* _tmp29_;
		ValadocHighlighterCodeTokenType _tmp30_;
		ValaHashMap* _tmp31_;
		ValadocHighlighterCodeTokenType _tmp32_;
		ValaHashMap* _tmp33_;
		ValadocHighlighterCodeTokenType _tmp34_;
		ValaHashMap* _tmp35_;
		ValadocHighlighterCodeTokenType _tmp36_;
		ValaHashMap* _tmp37_;
		ValadocHighlighterCodeTokenType _tmp38_;
		ValaHashMap* _tmp39_;
		ValadocHighlighterCodeTokenType _tmp40_;
		ValaHashMap* _tmp41_;
		ValadocHighlighterCodeTokenType _tmp42_;
		ValaHashMap* _tmp43_;
		ValadocHighlighterCodeTokenType _tmp44_;
		ValaHashMap* _tmp45_;
		ValadocHighlighterCodeTokenType _tmp46_;
		ValaHashMap* _tmp47_;
		ValadocHighlighterCodeTokenType _tmp48_;
		ValaHashMap* _tmp49_;
		ValadocHighlighterCodeTokenType _tmp50_;
		ValaHashMap* _tmp51_;
		ValadocHighlighterCodeTokenType _tmp52_;
		ValaHashMap* _tmp53_;
		ValadocHighlighterCodeTokenType _tmp54_;
		ValaHashMap* _tmp55_;
		ValadocHighlighterCodeTokenType _tmp56_;
		ValaHashMap* _tmp57_;
		ValadocHighlighterCodeTokenType _tmp58_;
		ValaHashMap* _tmp59_;
		ValadocHighlighterCodeTokenType _tmp60_;
		ValaHashMap* _tmp61_;
		ValadocHighlighterCodeTokenType _tmp62_;
		ValaHashMap* _tmp63_;
		ValadocHighlighterCodeTokenType _tmp64_;
		ValaHashMap* _tmp65_;
		ValadocHighlighterCodeTokenType _tmp66_;
		ValaHashMap* _tmp67_;
		ValadocHighlighterCodeTokenType _tmp68_;
		ValaHashMap* _tmp69_;
		ValadocHighlighterCodeTokenType _tmp70_;
		ValaHashMap* _tmp71_;
		ValadocHighlighterCodeTokenType _tmp72_;
		ValaHashMap* _tmp73_;
		ValadocHighlighterCodeTokenType _tmp74_;
		ValaHashMap* _tmp75_;
		ValadocHighlighterCodeTokenType _tmp76_;
		ValaHashMap* _tmp77_;
		ValadocHighlighterCodeTokenType _tmp78_;
		ValaHashMap* _tmp79_;
		ValadocHighlighterCodeTokenType _tmp80_;
		ValaHashMap* _tmp81_;
		ValadocHighlighterCodeTokenType _tmp82_;
		ValaHashMap* _tmp83_;
		ValadocHighlighterCodeTokenType _tmp84_;
		ValaHashMap* _tmp85_;
		ValadocHighlighterCodeTokenType _tmp86_;
		ValaHashMap* _tmp87_;
		ValadocHighlighterCodeTokenType _tmp88_;
		ValaHashMap* _tmp89_;
		ValadocHighlighterCodeTokenType _tmp90_;
		ValaHashMap* _tmp91_;
		ValadocHighlighterCodeTokenType _tmp92_;
		ValaHashMap* _tmp93_;
		ValadocHighlighterCodeTokenType _tmp94_;
		ValaHashMap* _tmp95_;
		ValadocHighlighterCodeTokenType _tmp96_;
		ValaHashMap* _tmp97_;
		ValadocHighlighterCodeTokenType _tmp98_;
		ValaHashMap* _tmp99_;
		ValadocHighlighterCodeTokenType _tmp100_;
		ValaHashMap* _tmp101_;
		ValadocHighlighterCodeTokenType _tmp102_;
		ValaHashMap* _tmp103_;
		ValadocHighlighterCodeTokenType _tmp104_;
		ValaHashMap* _tmp105_;
		ValadocHighlighterCodeTokenType _tmp106_;
		ValaHashMap* _tmp107_;
		ValadocHighlighterCodeTokenType _tmp108_;
		ValaHashMap* _tmp109_;
		ValadocHighlighterCodeTokenType _tmp110_;
		ValaHashMap* _tmp111_;
		ValadocHighlighterCodeTokenType _tmp112_;
		ValaHashMap* _tmp113_;
		ValadocHighlighterCodeTokenType _tmp114_;
		ValaHashMap* _tmp115_;
		ValadocHighlighterCodeTokenType _tmp116_;
		ValaHashMap* _tmp117_;
		ValadocHighlighterCodeTokenType _tmp118_;
		ValaHashMap* _tmp119_;
		ValadocHighlighterCodeTokenType _tmp120_;
		ValaHashMap* _tmp121_;
		ValadocHighlighterCodeTokenType _tmp122_;
		ValaHashMap* _tmp123_;
		ValadocHighlighterCodeTokenType _tmp124_;
		ValaHashMap* _tmp125_;
		ValadocHighlighterCodeTokenType _tmp126_;
		ValaHashMap* _tmp127_;
		ValadocHighlighterCodeTokenType _tmp128_;
		_tmp1_ = g_str_hash;
		_tmp2_ = g_str_equal;
		_tmp3_ = g_direct_equal;
		_tmp4_ = vala_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, VALADOC_HIGHLIGHTER_TYPE_CODE_TOKEN_TYPE, (GBoxedCopyFunc) _valadoc_highlighter_code_token_type_dup, (GDestroyNotify) g_free, _tmp1_, _tmp2_, _tmp3_);
		_vala_map_unref0 (self->priv->c_keywords);
		self->priv->c_keywords = _tmp4_;
		_tmp5_ = self->priv->c_keywords;
		_tmp6_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp5_, "auto", (gpointer) ((gintptr) (&_tmp6_)));
		_tmp7_ = self->priv->c_keywords;
		_tmp8_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp7_, "char", (gpointer) ((gintptr) (&_tmp8_)));
		_tmp9_ = self->priv->c_keywords;
		_tmp10_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp9_, "const", (gpointer) ((gintptr) (&_tmp10_)));
		_tmp11_ = self->priv->c_keywords;
		_tmp12_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp11_, "double", (gpointer) ((gintptr) (&_tmp12_)));
		_tmp13_ = self->priv->c_keywords;
		_tmp14_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp13_, "extern", (gpointer) ((gintptr) (&_tmp14_)));
		_tmp15_ = self->priv->c_keywords;
		_tmp16_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp15_, "int", (gpointer) ((gintptr) (&_tmp16_)));
		_tmp17_ = self->priv->c_keywords;
		_tmp18_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp17_, "float", (gpointer) ((gintptr) (&_tmp18_)));
		_tmp19_ = self->priv->c_keywords;
		_tmp20_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp19_, "long", (gpointer) ((gintptr) (&_tmp20_)));
		_tmp21_ = self->priv->c_keywords;
		_tmp22_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp21_, "register", (gpointer) ((gintptr) (&_tmp22_)));
		_tmp23_ = self->priv->c_keywords;
		_tmp24_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp23_, "short", (gpointer) ((gintptr) (&_tmp24_)));
		_tmp25_ = self->priv->c_keywords;
		_tmp26_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp25_, "signed", (gpointer) ((gintptr) (&_tmp26_)));
		_tmp27_ = self->priv->c_keywords;
		_tmp28_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp27_, "static", (gpointer) ((gintptr) (&_tmp28_)));
		_tmp29_ = self->priv->c_keywords;
		_tmp30_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp29_, "unsigned", (gpointer) ((gintptr) (&_tmp30_)));
		_tmp31_ = self->priv->c_keywords;
		_tmp32_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp31_, "void", (gpointer) ((gintptr) (&_tmp32_)));
		_tmp33_ = self->priv->c_keywords;
		_tmp34_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp33_, "volatile", (gpointer) ((gintptr) (&_tmp34_)));
		_tmp35_ = self->priv->c_keywords;
		_tmp36_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp35_, "gboolean", (gpointer) ((gintptr) (&_tmp36_)));
		_tmp37_ = self->priv->c_keywords;
		_tmp38_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp37_, "gpointer", (gpointer) ((gintptr) (&_tmp38_)));
		_tmp39_ = self->priv->c_keywords;
		_tmp40_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp39_, "gconstpointer", (gpointer) ((gintptr) (&_tmp40_)));
		_tmp41_ = self->priv->c_keywords;
		_tmp42_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp41_, "gchar", (gpointer) ((gintptr) (&_tmp42_)));
		_tmp43_ = self->priv->c_keywords;
		_tmp44_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp43_, "guchar", (gpointer) ((gintptr) (&_tmp44_)));
		_tmp45_ = self->priv->c_keywords;
		_tmp46_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp45_, "gint", (gpointer) ((gintptr) (&_tmp46_)));
		_tmp47_ = self->priv->c_keywords;
		_tmp48_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp47_, "guint", (gpointer) ((gintptr) (&_tmp48_)));
		_tmp49_ = self->priv->c_keywords;
		_tmp50_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp49_, "gshort", (gpointer) ((gintptr) (&_tmp50_)));
		_tmp51_ = self->priv->c_keywords;
		_tmp52_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp51_, "gushort", (gpointer) ((gintptr) (&_tmp52_)));
		_tmp53_ = self->priv->c_keywords;
		_tmp54_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp53_, "glong", (gpointer) ((gintptr) (&_tmp54_)));
		_tmp55_ = self->priv->c_keywords;
		_tmp56_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp55_, "gulong", (gpointer) ((gintptr) (&_tmp56_)));
		_tmp57_ = self->priv->c_keywords;
		_tmp58_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp57_, "gint8", (gpointer) ((gintptr) (&_tmp58_)));
		_tmp59_ = self->priv->c_keywords;
		_tmp60_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp59_, "guint8", (gpointer) ((gintptr) (&_tmp60_)));
		_tmp61_ = self->priv->c_keywords;
		_tmp62_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp61_, "gint16", (gpointer) ((gintptr) (&_tmp62_)));
		_tmp63_ = self->priv->c_keywords;
		_tmp64_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp63_, "guint16", (gpointer) ((gintptr) (&_tmp64_)));
		_tmp65_ = self->priv->c_keywords;
		_tmp66_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp65_, "gint32", (gpointer) ((gintptr) (&_tmp66_)));
		_tmp67_ = self->priv->c_keywords;
		_tmp68_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp67_, "guint32", (gpointer) ((gintptr) (&_tmp68_)));
		_tmp69_ = self->priv->c_keywords;
		_tmp70_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp69_, "gint64", (gpointer) ((gintptr) (&_tmp70_)));
		_tmp71_ = self->priv->c_keywords;
		_tmp72_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp71_, "guint64", (gpointer) ((gintptr) (&_tmp72_)));
		_tmp73_ = self->priv->c_keywords;
		_tmp74_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp73_, "gfloat", (gpointer) ((gintptr) (&_tmp74_)));
		_tmp75_ = self->priv->c_keywords;
		_tmp76_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp75_, "gdouble", (gpointer) ((gintptr) (&_tmp76_)));
		_tmp77_ = self->priv->c_keywords;
		_tmp78_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp77_, "gsize", (gpointer) ((gintptr) (&_tmp78_)));
		_tmp79_ = self->priv->c_keywords;
		_tmp80_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp79_, "gssize", (gpointer) ((gintptr) (&_tmp80_)));
		_tmp81_ = self->priv->c_keywords;
		_tmp82_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp81_, "goffset", (gpointer) ((gintptr) (&_tmp82_)));
		_tmp83_ = self->priv->c_keywords;
		_tmp84_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp83_, "gintptr", (gpointer) ((gintptr) (&_tmp84_)));
		_tmp85_ = self->priv->c_keywords;
		_tmp86_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE;
		vala_map_set ((ValaMap*) _tmp85_, "guintptr", (gpointer) ((gintptr) (&_tmp86_)));
		_tmp87_ = self->priv->c_keywords;
		_tmp88_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_LITERAL;
		vala_map_set ((ValaMap*) _tmp87_, "NULL", (gpointer) ((gintptr) (&_tmp88_)));
		_tmp89_ = self->priv->c_keywords;
		_tmp90_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_LITERAL;
		vala_map_set ((ValaMap*) _tmp89_, "TRUE", (gpointer) ((gintptr) (&_tmp90_)));
		_tmp91_ = self->priv->c_keywords;
		_tmp92_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_LITERAL;
		vala_map_set ((ValaMap*) _tmp91_, "FALSE", (gpointer) ((gintptr) (&_tmp92_)));
		_tmp93_ = self->priv->c_keywords;
		_tmp94_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp93_, "break", (gpointer) ((gintptr) (&_tmp94_)));
		_tmp95_ = self->priv->c_keywords;
		_tmp96_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp95_, "case", (gpointer) ((gintptr) (&_tmp96_)));
		_tmp97_ = self->priv->c_keywords;
		_tmp98_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp97_, "continue", (gpointer) ((gintptr) (&_tmp98_)));
		_tmp99_ = self->priv->c_keywords;
		_tmp100_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp99_, "default", (gpointer) ((gintptr) (&_tmp100_)));
		_tmp101_ = self->priv->c_keywords;
		_tmp102_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp101_, "do", (gpointer) ((gintptr) (&_tmp102_)));
		_tmp103_ = self->priv->c_keywords;
		_tmp104_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp103_, "else", (gpointer) ((gintptr) (&_tmp104_)));
		_tmp105_ = self->priv->c_keywords;
		_tmp106_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp105_, "enum", (gpointer) ((gintptr) (&_tmp106_)));
		_tmp107_ = self->priv->c_keywords;
		_tmp108_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp107_, "for", (gpointer) ((gintptr) (&_tmp108_)));
		_tmp109_ = self->priv->c_keywords;
		_tmp110_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp109_, "goto", (gpointer) ((gintptr) (&_tmp110_)));
		_tmp111_ = self->priv->c_keywords;
		_tmp112_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp111_, "if", (gpointer) ((gintptr) (&_tmp112_)));
		_tmp113_ = self->priv->c_keywords;
		_tmp114_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp113_, "return", (gpointer) ((gintptr) (&_tmp114_)));
		_tmp115_ = self->priv->c_keywords;
		_tmp116_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp115_, "sizeof", (gpointer) ((gintptr) (&_tmp116_)));
		_tmp117_ = self->priv->c_keywords;
		_tmp118_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp117_, "struct", (gpointer) ((gintptr) (&_tmp118_)));
		_tmp119_ = self->priv->c_keywords;
		_tmp120_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp119_, "switch", (gpointer) ((gintptr) (&_tmp120_)));
		_tmp121_ = self->priv->c_keywords;
		_tmp122_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp121_, "typedef", (gpointer) ((gintptr) (&_tmp122_)));
		_tmp123_ = self->priv->c_keywords;
		_tmp124_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp123_, "union", (gpointer) ((gintptr) (&_tmp124_)));
		_tmp125_ = self->priv->c_keywords;
		_tmp126_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp125_, "while", (gpointer) ((gintptr) (&_tmp126_)));
		_tmp127_ = self->priv->c_keywords;
		_tmp128_ = VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD;
		vala_map_set ((ValaMap*) _tmp127_, "assert", (gpointer) ((gintptr) (&_tmp128_)));
	}
	enable_string_templates = FALSE;
	enable_preprocessor_define = TRUE;
	enable_preprocessor_include = TRUE;
	enable_keyword_escape = FALSE;
	enabel_verbatim_string = FALSE;
	_tmp129_ = self->priv->c_keywords;
	_tmp130_ = valadoc_highlighter_code_scanner_new (source_code, enable_string_templates, enabel_verbatim_string, enable_preprocessor_define, enable_preprocessor_include, enable_keyword_escape, _tmp129_);
	scanner = _tmp130_;
	_tmp131_ = valadoc_highlighter_highlighter_highlight_code (self, (ValadocHighlighterScanner*) scanner);
	result = _tmp131_;
	_g_object_unref0 (scanner);
	return result;
}

/**
 * Used to highlight C source code.
 */
ValadocContentRun*
valadoc_highlighter_highlighter_highlight_xml (ValadocHighlighterHighlighter* self,
                                               const gchar* source_code)
{
	ValadocHighlighterXmlScanner* scanner = NULL;
	ValadocHighlighterXmlScanner* _tmp0_;
	ValadocContentRun* _tmp1_;
	ValadocContentRun* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (source_code != NULL, NULL);
	_tmp0_ = valadoc_highlighter_xml_scanner_new (source_code);
	scanner = _tmp0_;
	_tmp1_ = valadoc_highlighter_highlighter_highlight_code (self, (ValadocHighlighterScanner*) scanner);
	result = _tmp1_;
	_g_object_unref0 (scanner);
	return result;
}

/**
 * Used to highlight source code.
 */
static ValadocContentRun*
valadoc_highlighter_highlighter_highlight_code (ValadocHighlighterHighlighter* self,
                                                ValadocHighlighterScanner* scanner)
{
	ValadocContentRun* code = NULL;
	ValadocContentRun* _tmp0_;
	ValadocContentRun* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (scanner != NULL, NULL);
	_tmp0_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_MONOSPACED);
	code = _tmp0_;
	{
		ValadocHighlighterCodeToken* token = NULL;
		ValadocHighlighterCodeToken* _tmp1_;
		_tmp1_ = valadoc_highlighter_scanner_next (scanner);
		token = _tmp1_;
		{
			gboolean _tmp2_ = FALSE;
			_tmp2_ = TRUE;
			while (TRUE) {
				ValadocHighlighterCodeToken* _tmp4_;
				ValadocHighlighterCodeTokenType _tmp5_;
				ValadocHighlighterCodeTokenType _tmp6_;
				ValadocHighlighterCodeToken* _tmp7_;
				ValadocHighlighterCodeTokenType _tmp8_;
				ValadocHighlighterCodeTokenType _tmp9_;
				if (!_tmp2_) {
					ValadocHighlighterCodeToken* _tmp3_;
					_tmp3_ = valadoc_highlighter_scanner_next (scanner);
					_valadoc_highlighter_code_token_unref0 (token);
					token = _tmp3_;
				}
				_tmp2_ = FALSE;
				_tmp4_ = token;
				_tmp5_ = valadoc_highlighter_code_token_get_token_type (_tmp4_);
				_tmp6_ = _tmp5_;
				if (!(_tmp6_ != VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_EOF)) {
					break;
				}
				_tmp7_ = token;
				_tmp8_ = valadoc_highlighter_code_token_get_token_type (_tmp7_);
				_tmp9_ = _tmp8_;
				switch (_tmp9_) {
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_PREPROCESSOR:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp10_;
						ValadocContentRun* _tmp11_;
						ValaList* _tmp12_;
						ValaList* _tmp13_;
						ValadocHighlighterCodeToken* _tmp14_;
						const gchar* _tmp15_;
						const gchar* _tmp16_;
						ValadocContentText* _tmp17_;
						ValadocContentText* _tmp18_;
						ValadocContentRun* _tmp19_;
						ValaList* _tmp20_;
						ValaList* _tmp21_;
						ValadocContentRun* _tmp22_;
						_tmp10_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_LANG_PREPROCESSOR);
						run = _tmp10_;
						_tmp11_ = run;
						_tmp12_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp11_);
						_tmp13_ = _tmp12_;
						_tmp14_ = token;
						_tmp15_ = valadoc_highlighter_code_token_get_content (_tmp14_);
						_tmp16_ = _tmp15_;
						_tmp17_ = valadoc_content_text_new (_tmp16_);
						_tmp18_ = _tmp17_;
						vala_collection_add ((ValaCollection*) _tmp13_, (ValadocContentInline*) _tmp18_);
						_g_object_unref0 (_tmp18_);
						_tmp19_ = code;
						_tmp20_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp19_);
						_tmp21_ = _tmp20_;
						_tmp22_ = run;
						vala_collection_add ((ValaCollection*) _tmp21_, (ValadocContentInline*) _tmp22_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_COMMENT:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp23_;
						ValadocContentRun* _tmp24_;
						ValaList* _tmp25_;
						ValaList* _tmp26_;
						ValadocHighlighterCodeToken* _tmp27_;
						const gchar* _tmp28_;
						const gchar* _tmp29_;
						ValadocContentText* _tmp30_;
						ValadocContentText* _tmp31_;
						ValadocContentRun* _tmp32_;
						ValaList* _tmp33_;
						ValaList* _tmp34_;
						ValadocContentRun* _tmp35_;
						_tmp23_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_LANG_COMMENT);
						run = _tmp23_;
						_tmp24_ = run;
						_tmp25_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp24_);
						_tmp26_ = _tmp25_;
						_tmp27_ = token;
						_tmp28_ = valadoc_highlighter_code_token_get_content (_tmp27_);
						_tmp29_ = _tmp28_;
						_tmp30_ = valadoc_content_text_new (_tmp29_);
						_tmp31_ = _tmp30_;
						vala_collection_add ((ValaCollection*) _tmp26_, (ValadocContentInline*) _tmp31_);
						_g_object_unref0 (_tmp31_);
						_tmp32_ = code;
						_tmp33_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp32_);
						_tmp34_ = _tmp33_;
						_tmp35_ = run;
						vala_collection_add ((ValaCollection*) _tmp34_, (ValadocContentInline*) _tmp35_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_KEYWORD:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp36_;
						ValadocContentRun* _tmp37_;
						ValaList* _tmp38_;
						ValaList* _tmp39_;
						ValadocHighlighterCodeToken* _tmp40_;
						const gchar* _tmp41_;
						const gchar* _tmp42_;
						ValadocContentText* _tmp43_;
						ValadocContentText* _tmp44_;
						ValadocContentRun* _tmp45_;
						ValaList* _tmp46_;
						ValaList* _tmp47_;
						ValadocContentRun* _tmp48_;
						_tmp36_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_LANG_KEYWORD);
						run = _tmp36_;
						_tmp37_ = run;
						_tmp38_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp37_);
						_tmp39_ = _tmp38_;
						_tmp40_ = token;
						_tmp41_ = valadoc_highlighter_code_token_get_content (_tmp40_);
						_tmp42_ = _tmp41_;
						_tmp43_ = valadoc_content_text_new (_tmp42_);
						_tmp44_ = _tmp43_;
						vala_collection_add ((ValaCollection*) _tmp39_, (ValadocContentInline*) _tmp44_);
						_g_object_unref0 (_tmp44_);
						_tmp45_ = code;
						_tmp46_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp45_);
						_tmp47_ = _tmp46_;
						_tmp48_ = run;
						vala_collection_add ((ValaCollection*) _tmp47_, (ValadocContentInline*) _tmp48_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_LITERAL:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp49_;
						ValadocContentRun* _tmp50_;
						ValaList* _tmp51_;
						ValaList* _tmp52_;
						ValadocHighlighterCodeToken* _tmp53_;
						const gchar* _tmp54_;
						const gchar* _tmp55_;
						ValadocContentText* _tmp56_;
						ValadocContentText* _tmp57_;
						ValadocContentRun* _tmp58_;
						ValaList* _tmp59_;
						ValaList* _tmp60_;
						ValadocContentRun* _tmp61_;
						_tmp49_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_LANG_LITERAL);
						run = _tmp49_;
						_tmp50_ = run;
						_tmp51_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp50_);
						_tmp52_ = _tmp51_;
						_tmp53_ = token;
						_tmp54_ = valadoc_highlighter_code_token_get_content (_tmp53_);
						_tmp55_ = _tmp54_;
						_tmp56_ = valadoc_content_text_new (_tmp55_);
						_tmp57_ = _tmp56_;
						vala_collection_add ((ValaCollection*) _tmp52_, (ValadocContentInline*) _tmp57_);
						_g_object_unref0 (_tmp57_);
						_tmp58_ = code;
						_tmp59_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp58_);
						_tmp60_ = _tmp59_;
						_tmp61_ = run;
						vala_collection_add ((ValaCollection*) _tmp60_, (ValadocContentInline*) _tmp61_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_TYPE:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp62_;
						ValadocContentRun* _tmp63_;
						ValaList* _tmp64_;
						ValaList* _tmp65_;
						ValadocHighlighterCodeToken* _tmp66_;
						const gchar* _tmp67_;
						const gchar* _tmp68_;
						ValadocContentText* _tmp69_;
						ValadocContentText* _tmp70_;
						ValadocContentRun* _tmp71_;
						ValaList* _tmp72_;
						ValaList* _tmp73_;
						ValadocContentRun* _tmp74_;
						_tmp62_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_LANG_BASIC_TYPE);
						run = _tmp62_;
						_tmp63_ = run;
						_tmp64_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp63_);
						_tmp65_ = _tmp64_;
						_tmp66_ = token;
						_tmp67_ = valadoc_highlighter_code_token_get_content (_tmp66_);
						_tmp68_ = _tmp67_;
						_tmp69_ = valadoc_content_text_new (_tmp68_);
						_tmp70_ = _tmp69_;
						vala_collection_add ((ValaCollection*) _tmp65_, (ValadocContentInline*) _tmp70_);
						_g_object_unref0 (_tmp70_);
						_tmp71_ = code;
						_tmp72_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp71_);
						_tmp73_ = _tmp72_;
						_tmp74_ = run;
						vala_collection_add ((ValaCollection*) _tmp73_, (ValadocContentInline*) _tmp74_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_ESCAPE:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp75_;
						ValadocContentRun* _tmp76_;
						ValaList* _tmp77_;
						ValaList* _tmp78_;
						ValadocHighlighterCodeToken* _tmp79_;
						const gchar* _tmp80_;
						const gchar* _tmp81_;
						ValadocContentText* _tmp82_;
						ValadocContentText* _tmp83_;
						ValadocContentRun* _tmp84_;
						ValaList* _tmp85_;
						ValaList* _tmp86_;
						ValadocContentRun* _tmp87_;
						_tmp75_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_LANG_ESCAPE);
						run = _tmp75_;
						_tmp76_ = run;
						_tmp77_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp76_);
						_tmp78_ = _tmp77_;
						_tmp79_ = token;
						_tmp80_ = valadoc_highlighter_code_token_get_content (_tmp79_);
						_tmp81_ = _tmp80_;
						_tmp82_ = valadoc_content_text_new (_tmp81_);
						_tmp83_ = _tmp82_;
						vala_collection_add ((ValaCollection*) _tmp78_, (ValadocContentInline*) _tmp83_);
						_g_object_unref0 (_tmp83_);
						_tmp84_ = code;
						_tmp85_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp84_);
						_tmp86_ = _tmp85_;
						_tmp87_ = run;
						vala_collection_add ((ValaCollection*) _tmp86_, (ValadocContentInline*) _tmp87_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_XML_ESCAPE:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp88_;
						ValadocContentRun* _tmp89_;
						ValaList* _tmp90_;
						ValaList* _tmp91_;
						ValadocHighlighterCodeToken* _tmp92_;
						const gchar* _tmp93_;
						const gchar* _tmp94_;
						ValadocContentText* _tmp95_;
						ValadocContentText* _tmp96_;
						ValadocContentRun* _tmp97_;
						ValaList* _tmp98_;
						ValaList* _tmp99_;
						ValadocContentRun* _tmp100_;
						_tmp88_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_XML_ESCAPE);
						run = _tmp88_;
						_tmp89_ = run;
						_tmp90_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp89_);
						_tmp91_ = _tmp90_;
						_tmp92_ = token;
						_tmp93_ = valadoc_highlighter_code_token_get_content (_tmp92_);
						_tmp94_ = _tmp93_;
						_tmp95_ = valadoc_content_text_new (_tmp94_);
						_tmp96_ = _tmp95_;
						vala_collection_add ((ValaCollection*) _tmp91_, (ValadocContentInline*) _tmp96_);
						_g_object_unref0 (_tmp96_);
						_tmp97_ = code;
						_tmp98_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp97_);
						_tmp99_ = _tmp98_;
						_tmp100_ = run;
						vala_collection_add ((ValaCollection*) _tmp99_, (ValadocContentInline*) _tmp100_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_XML_ELEMENT:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp101_;
						ValadocContentRun* _tmp102_;
						ValaList* _tmp103_;
						ValaList* _tmp104_;
						ValadocHighlighterCodeToken* _tmp105_;
						const gchar* _tmp106_;
						const gchar* _tmp107_;
						ValadocContentText* _tmp108_;
						ValadocContentText* _tmp109_;
						ValadocContentRun* _tmp110_;
						ValaList* _tmp111_;
						ValaList* _tmp112_;
						ValadocContentRun* _tmp113_;
						_tmp101_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_XML_ELEMENT);
						run = _tmp101_;
						_tmp102_ = run;
						_tmp103_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp102_);
						_tmp104_ = _tmp103_;
						_tmp105_ = token;
						_tmp106_ = valadoc_highlighter_code_token_get_content (_tmp105_);
						_tmp107_ = _tmp106_;
						_tmp108_ = valadoc_content_text_new (_tmp107_);
						_tmp109_ = _tmp108_;
						vala_collection_add ((ValaCollection*) _tmp104_, (ValadocContentInline*) _tmp109_);
						_g_object_unref0 (_tmp109_);
						_tmp110_ = code;
						_tmp111_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp110_);
						_tmp112_ = _tmp111_;
						_tmp113_ = run;
						vala_collection_add ((ValaCollection*) _tmp112_, (ValadocContentInline*) _tmp113_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_XML_ATTRIBUTE:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp114_;
						ValadocContentRun* _tmp115_;
						ValaList* _tmp116_;
						ValaList* _tmp117_;
						ValadocHighlighterCodeToken* _tmp118_;
						const gchar* _tmp119_;
						const gchar* _tmp120_;
						ValadocContentText* _tmp121_;
						ValadocContentText* _tmp122_;
						ValadocContentRun* _tmp123_;
						ValaList* _tmp124_;
						ValaList* _tmp125_;
						ValadocContentRun* _tmp126_;
						_tmp114_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_XML_ATTRIBUTE);
						run = _tmp114_;
						_tmp115_ = run;
						_tmp116_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp115_);
						_tmp117_ = _tmp116_;
						_tmp118_ = token;
						_tmp119_ = valadoc_highlighter_code_token_get_content (_tmp118_);
						_tmp120_ = _tmp119_;
						_tmp121_ = valadoc_content_text_new (_tmp120_);
						_tmp122_ = _tmp121_;
						vala_collection_add ((ValaCollection*) _tmp117_, (ValadocContentInline*) _tmp122_);
						_g_object_unref0 (_tmp122_);
						_tmp123_ = code;
						_tmp124_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp123_);
						_tmp125_ = _tmp124_;
						_tmp126_ = run;
						vala_collection_add ((ValaCollection*) _tmp125_, (ValadocContentInline*) _tmp126_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_XML_ATTRIBUTE_VALUE:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp127_;
						ValadocContentRun* _tmp128_;
						ValaList* _tmp129_;
						ValaList* _tmp130_;
						ValadocHighlighterCodeToken* _tmp131_;
						const gchar* _tmp132_;
						const gchar* _tmp133_;
						ValadocContentText* _tmp134_;
						ValadocContentText* _tmp135_;
						ValadocContentRun* _tmp136_;
						ValaList* _tmp137_;
						ValaList* _tmp138_;
						ValadocContentRun* _tmp139_;
						_tmp127_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_XML_ATTRIBUTE_VALUE);
						run = _tmp127_;
						_tmp128_ = run;
						_tmp129_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp128_);
						_tmp130_ = _tmp129_;
						_tmp131_ = token;
						_tmp132_ = valadoc_highlighter_code_token_get_content (_tmp131_);
						_tmp133_ = _tmp132_;
						_tmp134_ = valadoc_content_text_new (_tmp133_);
						_tmp135_ = _tmp134_;
						vala_collection_add ((ValaCollection*) _tmp130_, (ValadocContentInline*) _tmp135_);
						_g_object_unref0 (_tmp135_);
						_tmp136_ = code;
						_tmp137_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp136_);
						_tmp138_ = _tmp137_;
						_tmp139_ = run;
						vala_collection_add ((ValaCollection*) _tmp138_, (ValadocContentInline*) _tmp139_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_XML_COMMENT:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp140_;
						ValadocContentRun* _tmp141_;
						ValaList* _tmp142_;
						ValaList* _tmp143_;
						ValadocHighlighterCodeToken* _tmp144_;
						const gchar* _tmp145_;
						const gchar* _tmp146_;
						ValadocContentText* _tmp147_;
						ValadocContentText* _tmp148_;
						ValadocContentRun* _tmp149_;
						ValaList* _tmp150_;
						ValaList* _tmp151_;
						ValadocContentRun* _tmp152_;
						_tmp140_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_XML_COMMENT);
						run = _tmp140_;
						_tmp141_ = run;
						_tmp142_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp141_);
						_tmp143_ = _tmp142_;
						_tmp144_ = token;
						_tmp145_ = valadoc_highlighter_code_token_get_content (_tmp144_);
						_tmp146_ = _tmp145_;
						_tmp147_ = valadoc_content_text_new (_tmp146_);
						_tmp148_ = _tmp147_;
						vala_collection_add ((ValaCollection*) _tmp143_, (ValadocContentInline*) _tmp148_);
						_g_object_unref0 (_tmp148_);
						_tmp149_ = code;
						_tmp150_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp149_);
						_tmp151_ = _tmp150_;
						_tmp152_ = run;
						vala_collection_add ((ValaCollection*) _tmp151_, (ValadocContentInline*) _tmp152_);
						_g_object_unref0 (run);
						break;
					}
					case VALADOC_HIGHLIGHTER_CODE_TOKEN_TYPE_XML_CDATA:
					{
						ValadocContentRun* run = NULL;
						ValadocContentRun* _tmp153_;
						ValadocContentRun* _tmp154_;
						ValaList* _tmp155_;
						ValaList* _tmp156_;
						ValadocHighlighterCodeToken* _tmp157_;
						const gchar* _tmp158_;
						const gchar* _tmp159_;
						ValadocContentText* _tmp160_;
						ValadocContentText* _tmp161_;
						ValadocContentRun* _tmp162_;
						ValaList* _tmp163_;
						ValaList* _tmp164_;
						ValadocContentRun* _tmp165_;
						_tmp153_ = valadoc_content_run_new (VALADOC_CONTENT_RUN_STYLE_XML_CDATA);
						run = _tmp153_;
						_tmp154_ = run;
						_tmp155_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp154_);
						_tmp156_ = _tmp155_;
						_tmp157_ = token;
						_tmp158_ = valadoc_highlighter_code_token_get_content (_tmp157_);
						_tmp159_ = _tmp158_;
						_tmp160_ = valadoc_content_text_new (_tmp159_);
						_tmp161_ = _tmp160_;
						vala_collection_add ((ValaCollection*) _tmp156_, (ValadocContentInline*) _tmp161_);
						_g_object_unref0 (_tmp161_);
						_tmp162_ = code;
						_tmp163_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp162_);
						_tmp164_ = _tmp163_;
						_tmp165_ = run;
						vala_collection_add ((ValaCollection*) _tmp164_, (ValadocContentInline*) _tmp165_);
						_g_object_unref0 (run);
						break;
					}
					default:
					{
						ValadocContentRun* _tmp166_;
						ValaList* _tmp167_;
						ValaList* _tmp168_;
						ValadocHighlighterCodeToken* _tmp169_;
						const gchar* _tmp170_;
						const gchar* _tmp171_;
						ValadocContentText* _tmp172_;
						ValadocContentText* _tmp173_;
						_tmp166_ = code;
						_tmp167_ = valadoc_content_inline_content_get_content ((ValadocContentInlineContent*) _tmp166_);
						_tmp168_ = _tmp167_;
						_tmp169_ = token;
						_tmp170_ = valadoc_highlighter_code_token_get_content (_tmp169_);
						_tmp171_ = _tmp170_;
						_tmp172_ = valadoc_content_text_new (_tmp171_);
						_tmp173_ = _tmp172_;
						vala_collection_add ((ValaCollection*) _tmp168_, (ValadocContentInline*) _tmp173_);
						_g_object_unref0 (_tmp173_);
						break;
					}
				}
			}
		}
		_valadoc_highlighter_code_token_unref0 (token);
	}
	result = code;
	return result;
}

ValadocHighlighterHighlighter*
valadoc_highlighter_highlighter_construct (GType object_type)
{
	ValadocHighlighterHighlighter * self = NULL;
	self = (ValadocHighlighterHighlighter*) g_object_new (object_type, NULL);
	return self;
}

ValadocHighlighterHighlighter*
valadoc_highlighter_highlighter_new (void)
{
	return valadoc_highlighter_highlighter_construct (VALADOC_HIGHLIGHTER_TYPE_HIGHLIGHTER);
}

static void
valadoc_highlighter_highlighter_class_init (ValadocHighlighterHighlighterClass * klass,
                                            gpointer klass_data)
{
	valadoc_highlighter_highlighter_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ValadocHighlighterHighlighter_private_offset);
	G_OBJECT_CLASS (klass)->finalize = valadoc_highlighter_highlighter_finalize;
}

static void
valadoc_highlighter_highlighter_instance_init (ValadocHighlighterHighlighter * self,
                                               gpointer klass)
{
	self->priv = valadoc_highlighter_highlighter_get_instance_private (self);
}

static void
valadoc_highlighter_highlighter_finalize (GObject * obj)
{
	ValadocHighlighterHighlighter * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, VALADOC_HIGHLIGHTER_TYPE_HIGHLIGHTER, ValadocHighlighterHighlighter);
	_vala_map_unref0 (self->priv->vala_keywords);
	_vala_map_unref0 (self->priv->c_keywords);
	G_OBJECT_CLASS (valadoc_highlighter_highlighter_parent_class)->finalize (obj);
}

static GType
valadoc_highlighter_highlighter_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ValadocHighlighterHighlighterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valadoc_highlighter_highlighter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValadocHighlighterHighlighter), 0, (GInstanceInitFunc) valadoc_highlighter_highlighter_instance_init, NULL };
	GType valadoc_highlighter_highlighter_type_id;
	valadoc_highlighter_highlighter_type_id = g_type_register_static (G_TYPE_OBJECT, "ValadocHighlighterHighlighter", &g_define_type_info, 0);
	ValadocHighlighterHighlighter_private_offset = g_type_add_instance_private (valadoc_highlighter_highlighter_type_id, sizeof (ValadocHighlighterHighlighterPrivate));
	return valadoc_highlighter_highlighter_type_id;
}

GType
valadoc_highlighter_highlighter_get_type (void)
{
	static volatile gsize valadoc_highlighter_highlighter_type_id__once = 0;
	if (g_once_init_enter (&valadoc_highlighter_highlighter_type_id__once)) {
		GType valadoc_highlighter_highlighter_type_id;
		valadoc_highlighter_highlighter_type_id = valadoc_highlighter_highlighter_get_type_once ();
		g_once_init_leave (&valadoc_highlighter_highlighter_type_id__once, valadoc_highlighter_highlighter_type_id);
	}
	return valadoc_highlighter_highlighter_type_id__once;
}

